@@ -62,7 +62,7 @@ class InstallProgressStdout(au.InstallProgressHandler):
         if cur_chunk == total_chunks:
             sys.stdout.write('\n')
 
-def yield_tabular_lines(l, col_spacing=4, indent=0):
+def yield_tabular_lines(l, col_spacing=2, indent=0):
     if not l:
         return
     sl = []
@@ -118,7 +118,7 @@ def list_available_modules(pattern=r'.*', types=[], include_hidden=False, tags=[
     if quiet:
         all_toks = []
     else:
-        header = ['Name', 'Title', 'Type','Installed','Up to date', 'Store latest ver','Store data source ver', 'Local ver', 'Local data source ver', 'Size']
+        header = ['Name', 'Title', 'Type','Installed', 'Store ver','Store data ver', 'Local ver', 'Local data ver', 'Size']
         all_toks = [header]
     for module_name in au.search_remote(pattern):
         remote_info = au.get_remote_module_info(module_name)
@@ -135,16 +135,10 @@ def list_available_modules(pattern=r'.*', types=[], include_hidden=False, tags=[
         if local_info is not None:
             installed = 'yes'
             local_version = local_info.version
-            up_to_date = local_version == remote_info.latest_version
-            if up_to_date:
-                up_to_date = 'yes'
-            else:
-                up_to_date = ''
             local_datasource = local_info.datasource
         else:
             installed = ''
             local_version = ''
-            up_to_date = ''
             local_datasource = ''
         if quiet:
             toks = [module_name]
@@ -154,7 +148,6 @@ def list_available_modules(pattern=r'.*', types=[], include_hidden=False, tags=[
                 remote_info.title,
                 remote_info.type,
                 installed,
-                up_to_date,
                 remote_info.latest_version,
                 remote_info.datasource,
                 local_version,
@@ -221,16 +214,18 @@ def print_info(args):
         del remote_info.data_sources
         dump = yaml_string(remote_info)
         print(dump)
-    # output columns
-    print('output columns:')
-    conf = au.get_remote_module_config(module_name)
-    if 'output_columns' in conf:
-        output_columns = conf['output_columns']
-        for col in output_columns:
-            desc = ''
-            if 'desc' in col:
-                desc = col['desc']
-            print('  {}: {}'.format(col['title'], desc))
+        # output columns
+        print('output columns:')
+        conf = au.get_remote_module_config(module_name)
+        if 'output_columns' in conf:
+            output_columns = conf['output_columns']
+            for col in output_columns:
+                desc = ''
+                if 'desc' in col:
+                    desc = col['desc']
+                print('  {}: {}'.format(col['title'], desc))
+    else:
+        print('NOT IN STORE')
     if installed:
         print('INSTALLED')
         if args.local:
@@ -263,16 +258,19 @@ def install_modules(args):
     selected_install = {}
     for module_name in matching_names:
         remote_info = au.get_remote_module_info(module_name)
+        local_info = au.get_local_module_info(module_name)
         if args.version is None:
-            local_info = au.get_local_module_info(module_name)
             if local_info is not None:
                 local_ver = local_info.version
                 remote_ver = remote_info.latest_version
                 if not args.force and LooseVersion(local_ver) >= LooseVersion(remote_ver):
-                    print(f'{module_name}: latest is already installed. ({local_ver})')
+                    print(f'{module_name}: latest ({local_ver}) is already installed. Use -f/--force to overwrite')
                     continue
             selected_install[module_name] = remote_info.latest_version
         elif remote_info.has_version(args.version):
+            if not args.force and local_info is not None and LooseVersion(local_info.version) == LooseVersion(args.version):
+                print(f'{module_name}:{args.version} is already installed. Use -f/--force to overwrite')
+                continue
             selected_install[module_name] = args.version
         else:
             continue
@@ -299,8 +297,8 @@ def install_modules(args):
                 )
         if not(args.yes):
             while True:
-                resp = input('Proceed? (y/n) > ')
-                if resp == 'y':
+                resp = input('Proceed? ([y]/n) > ')
+                if resp == 'y' or resp=='':
                     break
                 if resp == 'n':
                     exit()
@@ -380,7 +378,6 @@ def install_base (args):
     base_modules = sys_conf.get(constants.base_modules_key,[])
     args = SimpleNamespace(modules=base_modules,
                             force_data=False,
-                            skip_installed=True,
                             version=None,
                             yes=True,
                             private=False,
@@ -462,7 +459,7 @@ parser_install_base = subparsers.add_parser('install-base',
 )
 parser_install_base.add_argument('-f','--force',
     action='store_true',
-    help='Overwrite existing moduels',
+    help='Overwrite existing modules',
 )
 parser_install_base.set_defaults(func=install_base)
 
@@ -483,11 +480,7 @@ parser_install.add_argument('-f','--force',
 )
 parser_install.add_argument('-d', '--force-data',
     action='store_true',
-    help='Force download new data even if not needed.'
-)
-parser_install.add_argument('--skip-installed',
-    action='store_true',
-    help='skips already installed modules.'
+    help='Download data even if latest data is already installed'
 )
 parser_install.add_argument('-y','--yes',
     action='store_true',
@@ -495,7 +488,7 @@ parser_install.add_argument('-y','--yes',
 )
 parser_install.add_argument('--skip-dependencies',
     action='store_true',
-    help='Skip installing dependencies of selected modules'
+    help='Skip installing dependencies'
 )
 parser_install.add_argument('-p','--private',
     action='store_true',
@@ -620,7 +613,7 @@ parser_publish.add_argument('-u',
                             )
 parser_publish.add_argument('-p',
                             '--password',
-                            help='password for the user.')
+                            help='password for the user. Enter at prompt if missing.')
 parser_publish.add_argument('--force-yes',
                             default=False,
                             action='store_true',
