@@ -32,6 +32,7 @@ import re
 import sys
 if sys.platform == 'win32' and sys.version_info >= (3,8):
     asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
+import shutil
 
 # Custom system conf
 pre_parser = argparse.ArgumentParser(add_help=False)
@@ -202,6 +203,11 @@ cravat_cmd_parser.add_argument('--silent',
     action='store_true',
     default=False,
     help='Runs silently.')
+cravat_cmd_parser.add_argument('--concise-report',
+    dest='concise_report',
+    action='store_true',
+    default=False,
+    help='Generate concise reports with default columns defined by each annotation module')
 
 def run(cmd_args):
     au.ready_resolution_console()
@@ -284,7 +290,6 @@ class Cravat (object):
                     if not self.args.silent:
                         print(msg)
                     raise InvalidReporter
-                
 
     def write_initial_status_json (self):
         status_fname = '{}.status.json'.format(self.run_name)
@@ -383,6 +388,21 @@ class Cravat (object):
                 print(f'  Removing {fn}')
             os.remove(fn)
 
+    def log_versions (self):
+        self.logger.info(f'version: open-cravat {au.get_current_package_version()}')
+        for mname, module in self.annotators.items():
+            if mname in au.mic.local:
+                version = au.mic.local[mname].conf['version']
+                self.logger.info(f'version: {mname} {version}')
+        if 'mapper' not in self.args.skip:
+            if self.mapper_name in au.mic.local:
+                self.logger.info(f'version: {self.mapper_name} {au.mic.local[self.mapper_name].conf["version"]}')
+        for mname in self.reports:
+            mname = mname + 'reporter'
+            if mname in au.mic.local:
+                version = au.mic.local[mname].conf['version']
+                self.logger.info(f'version: {mname} {version}')
+
     async def main (self):
         no_problem_in_run = True
         report_response = None
@@ -400,6 +420,7 @@ class Cravat (object):
                 print('Genome assembly: {}'.format(self.input_assembly))
             self.logger.info('input files: {}'.format(input_files_str))
             self.logger.info('input assembly: {}'.format(self.input_assembly))
+            self.log_versions()
             self.set_and_check_input_files()
             converter_ran = False
             if self.endlevel >= self.runlevels['converter'] and \
@@ -413,6 +434,12 @@ class Cravat (object):
                 if not self.args.silent:
                     print('finished in {0:.3f}s'.format(rtime))
                 converter_ran = True
+                if self.numinput == 0:
+                    msg = 'No variant found in input'
+                    if not self.args.silent:
+                        print(msg)
+                    self.logger.info(msg)
+                    exit()
             self.mapper_ran = False
             if self.endlevel >= self.runlevels['mapper'] and \
                     self.startlevel <= self.runlevels['mapper'] and \
@@ -473,10 +500,8 @@ class Cravat (object):
             if self.endlevel >= self.runlevels['reporter'] and \
                     self.startlevel <= self.runlevels['reporter'] and \
                     not 'reporter' in self.args.skip and \
-                    (
-                        self.aggregator_ran or \
-                        len(self.reports) > 0
-                    ):
+                    self.aggregator_ran and \
+                    self.reports:
                 if not self.args.silent:
                     print('Running reporter...')
                 no_problem_in_run, report_response = await self.run_reporter()
@@ -509,7 +534,10 @@ class Cravat (object):
                 self.clean_up_at_end()
             if self.args.writeadmindb:
                 await self.write_admin_db(runtime, self.numinput)
-            return report_response
+            if report_response is not None and type(report_response) == list and len(report_response) == 1:
+                return report_response[list(report_response.keys())[0]]
+            else:
+                return report_response
 
     async def write_admin_db (self, runtime, numinput):
         if runtime is None or numinput is None:
@@ -541,34 +569,41 @@ class Cravat (object):
         cols_to_index = set()
         for sf in constants.base_smartfilters:
             cols_to_index |= util.filter_affected_cols(sf['filter'])
-        for linfo in self.annotators.values():
-            if linfo.smartfilters is not None:
-                for sf in linfo.smartfilters:
-                    cols_to_index |= util.filter_affected_cols(sf['filter'])
-                mname = linfo.name
-                json_info = json.dumps(linfo.smartfilters)
-                cursor.execute(ins_template, (mname, json_info))
+        if self.annotator_ran:
+            for linfo in self.annotators.values():
+                if linfo.smartfilters is not None:
+                    for sf in linfo.smartfilters:
+                        cols_to_index |= util.filter_affected_cols(sf['filter'])
+                    mname = linfo.name
+                    json_info = json.dumps(linfo.smartfilters)
+                    cursor.execute(ins_template, (mname, json_info))
         cursor.execute('pragma table_info(variant)')
         variant_cols = {row[1] for row in cursor}
         cursor.execute('pragma table_info(gene)')
         gene_cols = {row[1] for row in cursor}
+        cursor.execute('select name from sqlite_master where type="index"')
+        existing_indices = {row[0] for row in cursor}
         for col in cols_to_index:
             if col in variant_cols:
-                q = f'create index sf_variant_{col} on variant ({col})'
-                if not self.args.silent:
-                    print(f'\tvariant {col}',end='',flush=True)
-                st = time.time()
-                cursor.execute(q)
-                if not self.args.silent:
-                    print(f'\tfinished in {time.time()-st:.3f}s')
+                index_name = f'sf_variant_{col}'
+                if index_name not in existing_indices:
+                    q = f'create index if not exists {index_name} on variant ({col})'
+                    if not self.args.silent:
+                        print(f'\tvariant {col}',end='',flush=True)
+                    st = time.time()
+                    cursor.execute(q)
+                    if not self.args.silent:
+                        print(f'\tfinished in {time.time()-st:.3f}s')
             if col in gene_cols:
-                q = f'create index sf_gene_{col} on gene ({col})'
-                if not self.args.silent:
-                    print(f'\tIndexing gene {col}',end='',flush=True)
-                st = time.time()
-                cursor.execute(q)
-                if not self.args.silent:
-                    print(f'\tfinished in {time.time()-st:.3f}s')
+                index_name = f'sf_gene_{col}'
+                if index_name not in existing_indices:
+                    q = f'create index if not exists {index_name} on gene ({col})'
+                    if not self.args.silent:
+                        print(f'\tgene {col}',end='',flush=True)
+                    st = time.time()
+                    cursor.execute(q)
+                    if not self.args.silent:
+                        print(f'\tfinished in {time.time()-st:.3f}s')
 
         conn.commit()
         cursor.close()
@@ -690,9 +725,26 @@ class Cravat (object):
                 if num_input > 1:
                     self.run_name += '_and_'+str(len(self.inputs)-1)+'_files'
         if num_input > 0 and self.inputs[0].endswith('.sqlite'):
-            self.append_mode = True  
+            self.append_mode = True
+            if self.args.skip is None:
+                self.args.skip = ['converter','mapper']
+            else:
+                if 'converter' not in self.args.skip:
+                    self.args.skip.append('converter')
+                if 'mapper' not in self.args.skip:
+                    self.args.skip.append('mapper')
+            if self.args.output_dir:
+                if self.run_name.endswith('.sqlite'):
+                    target_name = self.run_name
+                else:
+                    target_name = self.run_name+'.sqlite'
+                target_path = os.path.join(self.args.output_dir, target_name)
+                shutil.copyfile(self.inputs[0], target_path)
+                self.inputs[0] = target_path
             if self.run_name.endswith('.sqlite'):
                 self.run_name = self.run_name[:-7]
+        if self.args.skip is None:
+            self.args.skip = []
         self.output_dir = self.args.output_dir
         if self.output_dir == None:
             if num_input == 0 or first_non_url_input is None:
@@ -707,7 +759,10 @@ class Cravat (object):
                 self.args.__dict__[arg_key] = self.run_conf[arg_key]
         self.annotator_names = self.args.annotators
         if self.annotator_names == None:
-            self.annotators = au.get_local_module_infos_of_type('annotator')
+            if 'annotator' in self.args.skip:
+                self.annotators = {}
+            else:
+                self.annotators = au.get_local_module_infos_of_type('annotator')
         else:
             self.annotators = au.get_local_module_infos_by_names(self.annotator_names)
         self.excludes = self.args.excludes
@@ -725,7 +780,12 @@ class Cravat (object):
             self.verbose = False
         self.reports = self.args.reports
         if self.reports is None:
-            self.reports = ['excel']
+            if 'reporter' in self.args.skip:
+                self.reports = []
+            elif 'reporter' in self.cravat_conf:
+                self.reports = [self.cravat_conf['reporter'].replace('reporter','')]
+            else:
+                self.reports = []
         if self.args.genome is None:
             if constants.default_assembly_key in self.cravat_conf:
                 self.input_assembly = self.cravat_conf[constants.default_assembly_key]
@@ -738,8 +798,6 @@ class Cravat (object):
                 exit()
         else:
             self.input_assembly = self.args.genome
-        if self.args.skip is None:
-            self.args.skip = []
         if self.append_mode:
             self.args.endat = 'aggregator'
         try:
@@ -822,8 +880,10 @@ class Cravat (object):
                     crv.write_data(rd)
                 if crx:
                     crx.write_data(rd)
-            crv.close()
-            crx.close()
+            if crv:
+                crv.close()
+            if crx:
+                crx.close()
             self.crv_present = True
             self.crx_present = True
         # Gene
@@ -959,15 +1019,23 @@ class Cravat (object):
         genemapper.run()
 
     def run_genemapper_mp (self):
-        num_core = au.get_system_conf()['max_num_concurrent_annotators_per_job']
+        num_workers = au.get_max_num_concurrent_annotators_per_job()
+        if self.args.mp is not None:
+            try:
+                self.args.mp = int(self.args.mp)
+                if self.args.mp >= 1:
+                    num_workers = self.args.mp
+            except:
+                self.logger.exception('error handling mp argument:')
+        self.logger.info('num_workers: {}'.format(num_workers))
         reader = CravatReader(self.crvinput)
-        num_lines, chunksize, poss, len_poss, max_num_lines = reader.get_chunksize(num_core)
+        num_lines, chunksize, poss, len_poss, max_num_lines = reader.get_chunksize(num_workers)
         self.logger.info(f'input line chunksize={chunksize} total number of input lines={num_lines} number of chunks={len_poss}')
-        pool = mp.Pool(num_core, init_worker)
+        pool = mp.Pool(num_workers, init_worker)
         pos_no = 0
         while pos_no < len_poss:
             jobs = []
-            for i in range(num_core):
+            for i in range(num_workers):
                 if pos_no == len_poss:
                     break
                 (seekpos, num_lines) = poss[pos_no]
@@ -1183,12 +1251,18 @@ class Cravat (object):
         modules = au.get_local_module_infos_of_type('postaggregator')
         for module_name in modules:
             module = modules[module_name]
-            self.announce_module(module)
             cmd = [module.script_path, 
                    '-d', self.output_dir, 
                    '-n', self.run_name]
+            postagg_conf = {}
             if module.name in self.cravat_conf:
-                confs = json.dumps(self.cravat_conf[module.name])
+                postagg_conf.update(self.cravat_conf[module_name])
+            if module_name in self.conf._all:
+                postagg_conf.update(self.conf._all[module_name])
+            elif 'run' in self.conf._all and module_name in self.conf._all['run']:
+                postagg_conf.update(self.conf._all['run'][module_name])
+            if postagg_conf:
+                confs = json.dumps(postagg_conf)
                 confs = "'" + confs.replace("'", '"') + "'"
                 cmd.extend(['--confs', confs])
             if self.verbose:
@@ -1196,10 +1270,12 @@ class Cravat (object):
                     print(' '.join(cmd))
             post_agg_cls = util.load_class(module.script_path, 'CravatPostAggregator')
             post_agg = post_agg_cls(cmd, self.status_writer)
+            if post_agg.should_run_annotate:
+                self.announce_module(module)
             stime = time.time()
             post_agg.run()
             rtime = time.time() - stime
-            if not self.args.silent:
+            if not self.args.silent and post_agg.should_run_annotate:
                 print('finished in {0:.3f}s'.format(rtime))
 
     async def run_reporter (self):
@@ -1237,11 +1313,22 @@ class Cravat (object):
                         print(' '.join([str(k) + '=' + str(v) for k, v in arg_dict.items()]))
                 arg_dict['status_writer'] = self.status_writer
                 arg_dict['reporttypes'] = [module_name.replace('reporter', '')]
+                arg_dict['concise_report'] = self.args.concise_report
                 Reporter = util.load_class(module.script_path, 'Reporter')
                 reporter = Reporter(arg_dict)
                 await reporter.prep()
                 stime = time.time()
-                response[re.sub('reporter$', '', module_name)] = await reporter.run()
+                response_t = await reporter.run()
+                output_fns = None
+                if self.args.silent == False:
+                    response_type = type(response_t)
+                    if response_type == list:
+                        output_fns = ' '.join(response_t)
+                    elif response_type == str:
+                        output_fns = response_t
+                    if output_fns is not None:
+                        print(f'report created: {output_fns} ', end='', flush=True)
+                response[re.sub('reporter$', '', module_name)] = response_t
                 rtime = time.time() - stime
                 if not self.args.silent:
                     print('finished in {0:.3f}s'.format(rtime))
