@@ -22,8 +22,10 @@ class CravatFile(object):
 
     def _validate_col_type(self, col_type):
         if col_type not in self.valid_types:
-            raise Exception('Invalid type: %s. Choose from %s' \
-                    %(col_type, ', '.join(self.valid_types)))
+            raise Exception('Invalid column type {} in {}. Choose from {}'.format(
+                    col_type,
+                    self.path,
+                    ', '.join(self.valid_types)))
 
     def get_col_def(self, col_index):
         return self.columns[col_index]
@@ -152,13 +154,24 @@ class CravatReader (CravatFile):
                     if col_type == 'string':
                         out[col_name] = tok
                     elif col_type == 'int':
-                        out[col_name] = int(tok)
+                        try:
+                            out[col_name] = int(tok)
+                        except ValueError:
+                            try:
+                                out[col_name] = int(float(tok))
+                            except:
+                                out[col_name] = None
+                        except:
+                            out[col_name] = None
                     elif col_type == 'float':
-                        tok = json.loads(tok)
-                        if (type(tok) == list):
-                            out[col_name] = ','.join([str(v) for v in tok])
-                        else:
-                            out[col_name] = float(tok)
+                        try:
+                            tok = json.loads(tok)
+                            if (type(tok) == list):
+                                out[col_name] = ','.join([str(v) for v in tok])
+                            else:
+                                out[col_name] = float(tok)
+                        except:
+                            tok = None
             yield lnum, l, out
 
     def _open_file (self):
@@ -509,6 +522,7 @@ class ColumnDefinition (object):
         self.filterable = bool(d.get('filterable',True))
         self.link_format = d.get('link_format')
         self.genesummary = d.get('genesummary',False)
+        self.table = d.get('table', False)
 
     def from_row(self, row, order=None):
         if order is None:
@@ -552,7 +566,8 @@ class ColumnDefinition (object):
             'col_filterable': self.filterable,
             'link_format': self.link_format,
             'col_genesummary': self.genesummary,
-            'col_index': self.index
+            'col_index': self.index,
+            'table': self.table,
         }
     
     def __iter__(self): # Allows casting to dict
