@@ -237,7 +237,7 @@ async def save_filter_setting (request):
     if r is not None:
         q = 'delete from {} where datatype="filter" and name="{}"'.format(table, name)
         await cursor.execute(q)
-        conn.commit()
+        await conn.commit()
     q = 'replace into ' + table + ' values ("filter", "' + name + '", \'' + savedata + '\')'
     await cursor.execute(q)
     await conn.commit()
@@ -377,22 +377,25 @@ async def get_result (request):
 async def get_result_levels (request):
     queries = request.rel_url.query
     job_id, dbpath = await get_jobid_dbpath(request)
-    conn = await get_db_conn(dbpath)
-    cursor = await conn.cursor()
-    sql = 'select name from sqlite_master where type="table" and ' +\
-        'name like "%_header"'
-    await cursor.execute(sql)
-    ret = await cursor.fetchall()
-    if len(ret) > 0:
-        content = [v[0].split('_')[0] for v in ret]
-        content.insert(0, 'info')
-        content.insert(1,'filter')
+    if dbpath is None:
+        content = ['NODB']
     else:
-        content = []
-    content.remove('sample')
-    content.remove('mapping')
-    await cursor.close()
-    await conn.close()
+        conn = await get_db_conn(dbpath)
+        cursor = await conn.cursor()
+        sql = 'select name from sqlite_master where type="table" and ' +\
+            'name like "%_header"'
+        await cursor.execute(sql)
+        ret = await cursor.fetchall()
+        if len(ret) > 0:
+            content = [v[0].split('_')[0] for v in ret]
+            content.insert(0, 'info')
+            content.insert(1,'filter')
+        else:
+            content = []
+        content.remove('sample')
+        content.remove('mapping')
+        await cursor.close()
+        await conn.close()
     return web.json_response(content)
 
 async def get_jobid_dbpath (request):
@@ -616,6 +619,22 @@ async def serve_runwidget (request):
     content = await m.get_data(queries)
     return web.json_response(content)
 
+async def serve_webapp_runwidget (request):
+    module_name = request.match_info['module']
+    widget_name = request.match_info['widget']
+    queries = request.rel_url.query
+    tmp_queries = {}
+    for key in queries:
+        tmp_queries[key] = queries[key]
+    queries = tmp_queries
+    f, fn, d = imp.find_module(
+        'wg' + widget_name,
+        [os.path.join(au.get_modules_dir(), 'webapps', module_name, 'widgets', 'wg' + widget_name)]
+    )
+    m = imp.load_module(widget_name, f, fn, d)
+    content = await m.get_data(queries)
+    return web.json_response(content)
+
 async def serve_runwidget_post (request):
     path = 'wg' + request.match_info['module']
     job_id, dbpath = await get_jobid_dbpath(request)
@@ -729,4 +748,5 @@ routes.append(['POST', '/result/runwidget/{module}', serve_runwidget_post])
 routes.append(['GET', '/result/service/deletefiltersetting', delete_filter_setting])
 routes.append(['GET', '/result/service/smartfilters', load_smartfilters])
 routes.append(['GET', '/result/service/samples', get_samples])
+routes.append(['GET', '/webapps/{module}/widgets/{widget}', serve_webapp_runwidget])
 
