@@ -85,6 +85,13 @@ function submit () {
     submitOpts.note = note;
     document.querySelector('#submit-job-button').disabled = true;
     formData.append('options',JSON.stringify(submitOpts));
+    // AddtlAnalysis
+    for (addtlName of addtlAnalysis.names) {
+        let addtlData = addtlAnalysis.fetchers[addtlName]();
+        if (addtlData != undefined) {
+            formData.append(addtlName, addtlAnalysis.fetchers[addtlName]());
+        }
+    }
     var guiInputSizeLimit = parseInt(document.getElementById('settings_gui_input_size_limit').value);
     var sumInputSize = 0;
     for (var i = 0; i < inputFiles.length; i++) {
@@ -1013,6 +1020,7 @@ function populateAnnotators () {
                 GLOBALS.annotators = data
                 setTimeout(function () {
                     buildAnnotatorsSelector();
+                    resolve();
                 }, 100);
             }
         })
@@ -1378,6 +1386,13 @@ function onChangeAnnotatorGroupCheckbox (tags) {
                         } else {
                             c.classList.add('show');
                             c.classList.remove('hide');
+                            var groups = localModuleInfo[c.getAttribute('name')].groups;
+                            for (var groupNo = 0; groupNo < groups.length; groupNo++) {
+                                var group = groups[groupNo];
+                                var groupDiv = document.querySelector('div.checkbox-group-element[name="'+group+'"]');
+                                groupDiv.classList.add('show');
+                                groupDiv.classList.remove('hide');
+                            }
                         }
                     }
                 }
@@ -1399,36 +1414,6 @@ function checkBoxGroupAllNoneHandler (event) {
     });
 }
 
-function populateReports () {
-    return new Promise((resolve, reject) => {
-        $.ajax({
-            url:'/submit/reports',
-            type: 'GET',
-            success: function (data) {
-                GLOBALS.reports = data
-                buildReportSelector();
-                //resolve();
-            }
-        })
-    })
-}
-
-function buildReportSelector () {
-    var validReports = GLOBALS.reports.valid;
-    var checkData = [];
-    for (var i=0; i<validReports.length; i++) {
-        reportName = validReports[i];
-        checkData.push({
-            name: reportName,
-            value: reportName,
-            label: reportName[0].toUpperCase()+reportName.slice(1),
-            checked: reportName === GLOBALS.reports.default
-        })
-    }
-    var reportDiv = document.getElementById('report-select-div');
-    buildCheckBoxGroup(checkData, reportDiv);
-}
-
 function onTabChange () {
     var submitcontentdiv = document.getElementById('submitcontentdiv');
     var jobdiv = document.getElementById('jobdiv');
@@ -1945,3 +1930,80 @@ function importJob() {
     showSpinner();
     req.send(fileSel.files[0]);
 }
+
+// Additional analysis stuff. Currently just casecontrol. Design expected to change when more added.
+const addtlAnalysis = {
+    names: [],
+    fetchers: {},
+};
+
+function populateAddtlAnalysis () {
+    let display = false;
+    let addtlWrapper = $('#addtl-analysis-content');
+    addtlWrapper.empty();
+    display = display || populateCaseControl(addtlWrapper)===true;
+    if (display) {
+        $('#addtl-analysis-div').css('display','');
+    }
+}
+
+function populateCaseControl (outer) {
+    if ( ! localModuleInfo.hasOwnProperty('casecontrol')) {
+        return false
+    }
+    let wrapper = $(getEl('div'))
+        .attr('id','case-control-wrapper')
+        .addClass('addtl-analysis-wrapper')
+    outer.append(wrapper);
+    let d1 = $(getEl('div'));
+    wrapper.append(d1);
+    let cohortsInput = $(getEl('input'))
+        .attr('id','case-control-cohorts')
+        .attr('type','file')
+        .css('display','none');
+    d1.append(cohortsInput);
+    let cohortsLabel = $(getEl('label'))
+        .attr('for','case-control-cohorts')
+        .text('Case-Control cohorts')
+        .attr('title','Compare variant distribution across case and control cohorts. See documentation for details.');
+    d1.append(cohortsLabel);
+    let helpIcon = $(getEl('a'))
+        .attr('id','case-control-help')
+        .attr('target','_blank')
+        .attr('href','https://github.com/KarchinLab/open-cravat/wiki/Case-Control')
+        .append($(getEl('img')).attr('src','../help.png').attr('id','case-control-help-img'));
+    d1.append(helpIcon);
+    let d2 = $(getEl('div'))
+    wrapper.append(d2);
+    let spanDefaultText = 'No file selected'
+    let filenameSpan = $(getEl('span'))
+        .attr('id','case-control-filename')
+        .text(spanDefaultText);
+    d2.append(filenameSpan);
+    let clearBtn = $(getEl('button'))
+        .click(event => {
+            cohortsInput.val('').trigger('change');
+        })
+        .text('X')
+        .addClass('butn')
+        .css('display','none');
+    d2.append(clearBtn);
+    cohortsInput.change(event => {
+        let files = event.target.files;
+        if (files.length > 0) {
+            filenameSpan.text(files[0].name);
+            clearBtn.css('display','');
+        } else {
+            filenameSpan.text(spanDefaultText);
+            clearBtn.css('display','none');
+        }
+    })
+    addtlAnalysis.names.push('casecontrol');
+    addtlAnalysis.fetchers.casecontrol = function () {
+        let files = cohortsInput[0].files;
+        if (files.length > 0) {
+            return files[0];
+        }
+    }    
+    return true
+}
